==> flutterbudpay-0.0.1.tar.gz: example/lib/newpage.dart <==
import 'dart:developer';
import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';
import 'package:flutterbudpay/flutterbudpay.dart';

class Newpage extends StatefulWidget {
  const Newpage({Key? key}) : super(key: key);

  @override
  _NewpageState createState() => _NewpageState();
}

class _NewpageState extends State<Newpage> {
  // var currency = ["USD", "NGN", "GBP", "EUR", "KES", "GHS", "EGP", "CFA"];
  var currency = ["USD", "NGN"];
  // Initial Selected Value
  String dropdownvalue = 'NGN';
  TextEditingController phoneController = TextEditingController();
  bool isloading = false;
  final plugin = Budpay();
  final _scaffoldKey = GlobalKey<ScaffoldState>();
  final _formKey = GlobalKey<FormState>();

  @override
  void initState() {
    plugin.initialize(
        publicKey: "pk_test_oppvguyfnlna4f1eidl1bqrkxrxfszgdvgwq1q",
        secretKey: "sk_test_genllkfsimb3wrqamv02hcqbr3fuo1alekr7cpy");
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: Color(0xff6C30F4),
        title: Text("BUDPAY SDK SAMPLE"),
      ),
      body: Container(
        child: Center(
          child: Form(
            key: _formKey,
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                DropdownButton(
                  // Initial Value
                  value: dropdownvalue,

                  // Down Arrow Icon
                  icon: const Icon(Icons.keyboard_arrow_down),

                  // Array list of items
                  items: currency.map((String items) {
                    return DropdownMenuItem(
                      value: items,
                      child: Text(items),
                    );
                  }).toList(),
                  // After selecting the desired option,it will
                  // change button value to selected value
                  onChanged: (String? newValue) {
                    setState(() {
                      dropdownvalue = newValue!;
                    });
                  },
                ),
                SizedBox(
                  height: 30,
                ),
                Container(
                  decoration: const BoxDecoration(
                      color: Color(0xffF4F4F6),
                      borderRadius: BorderRadius.all(Radius.circular(15.0))),
                  padding: const EdgeInsets.symmetric(horizontal: 15),
                  child: TextFormField(
                    decoration: const InputDecoration(
                      fillColor: Color(0xffF4F4F6),
                      hintText: "1000",
                      hintStyle: TextStyle(
                          fontSize: 16.56, fontWeight: FontWeight.w500),
                      enabledBorder: OutlineInputBorder(
                        borderRadius: BorderRadius.all(Radius.circular(15.0)),
                        borderSide: BorderSide(color: Color(0xffF4F4F6)),
                      ),
                      focusedBorder: OutlineInputBorder(
                        borderRadius: BorderRadius.all(Radius.circular(15.0)),
                        borderSide: BorderSide(color: Color(0xffF4F4F6)),
                      ),
                      disabledBorder: OutlineInputBorder(
                        borderRadius: BorderRadius.all(Radius.circular(15.0)),
                        borderSide: BorderSide(color: Color(0xffF4F4F6)),
                      ),
                    ),
                    controller: phoneController,
                    keyboardType: TextInputType.phone,
                    onChanged: (value) {
                      // widget.email(value);
                      if (value.isEmpty) {
                        setState(() {
                          // widget.emailfield(true);
                        });
                      } else {
                        setState(() {});
                      }
                    },
                    validator: (value) {
                      if (value!.isEmpty) {
                        return "This field can't be empty";
                      }

                      return null;
                    },
                  ),
                ),
                SizedBox(
                  height: 50,
                ),
                GestureDetector(
                  child: Container(
                    decoration: BoxDecoration(
                        borderRadius:
                            const BorderRadius.all(Radius.circular(15)),
                        color: Color(0xff6C30F4)),
                    height: 65,
                    width: MediaQuery.of(context).size.width - 70,
                    padding: const EdgeInsets.symmetric(vertical: 15),
                    margin: const EdgeInsets.symmetric(
                        horizontal: 10, vertical: 10),
                    alignment: Alignment.center,
                    child: isloading
                        ? loadingWidget
                        : Text(
                            "Checkout",
                            style: TextStyle(color: Colors.white, fontSize: 20),
                          ),
                  ),
                  onTap: () {
                    if (_formKey.currentState!.validate()) {
                      _handleCheckout(context);
                    }
                  },
                )
              ],
            ),
          ),
        ),
      ),
    );
  }

  _handleCheckout(BuildContext context) async {
    setState(() => isloading = true);
    _formKey.currentState?.save();
    Charge charge = Charge()
      ..amount = int.parse(phoneController.text) * 100 // In base currency
      ..email = 'sdkapp@email.com'
      ..currency = dropdownvalue;
    // ..card = _getCardFromUI();

    charge.reference = _getReference();

    try {
      var response = await plugin.checkout(
        context,
        charge: charge,
      );
      log('Response = $response');
      setState(() => isloading = false);
      _updateStatus(response.reference, '$response');
    } catch (e) {
      setState(() => isloading = false);
      _showMessage("Check console for error");
      rethrow;
    }
  }

  String _getReference() {
    String platform;
    if (!kIsWeb) {
      if (Platform.isIOS) {
        platform = 'iOS';
      } else {
        platform = 'Android';
      }
    } else {
      platform = "WEB";
    }
    return 'ChargedFrom${platform}_${DateTime.now().millisecondsSinceEpoch}';
  }

  _updateStatus(String? reference, String message) {
    _showMessage('Reference: $reference \n Response: $message',
        const Duration(seconds: 7));
  }

  _showMessage(String message,
      [Duration duration = const Duration(seconds: 4)]) {
    ScaffoldMessenger.of(context).showSnackBar(SnackBar(
      content: Text(message),
      duration: duration,
      action: SnackBarAction(
          label: 'CLOSE',
          onPressed: () =>
              ScaffoldMessenger.of(context).removeCurrentSnackBar()),
    ));
  }
}

const loadingWidget = SpinKitThreeBounce(
  color: Colors.white,
  size: 30.0,
);

==> flutterbudpay-0.0.2.tar.gz: example/lib/newpage.dart <==
import 'dart:developer';
import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';
import 'package:flutterbudpay/flutterbudpay.dart';

import 'main.dart';

class Newpage extends StatefulWidget {
  const Newpage({Key? key}) : super(key: key);

  @override
  _NewpageState createState() => _NewpageState();
}

class _NewpageState extends State<Newpage> {
  // var currency = ["USD", "NGN", "GBP", "EUR", "KES", "GHS", "EGP", "CFA"];
  var currency = ["USD", "NGN"];
  // Initial Selected Value
  String dropdownvalue = 'NGN';
  TextEditingController phoneController = TextEditingController();
  bool isloading = false;
  final plugin = Budpay();
  final _scaffoldKey = GlobalKey<ScaffoldState>();
  final _formKey = GlobalKey<FormState>();
  bool check = false;

  @override
  void initState() {
    check = isDarkMode;
    plugin.initialize(
        publicKey: "pk_test_oppvguyfnlna4f1eidl1bqrkxrxfszgdvgwq1q",
        secretKey: "sk_test_genllkfsimb3wrqamv02hcqbr3fuo1alekr7cpy");
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    // final themeChange = Provider.of<DarkThemeProvider>(context);
    return Scaffold(
      appBar: AppBar(
        backgroundColor: const Color(0xff6C30F4),
        title: const Text("BUDPAY SDK SAMPLE"),
      ),
      body: Container(
        child: Center(
          child: Form(
            key: _formKey,
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                Checkbox(
                    value: check,
                    onChanged: (bool? value) {
                      setState(() {
                        check = !check;
                      });
                      if (!check) {
                        MyApp.of(context).changeTheme(ThemeMode.light);
                      } else {
                        MyApp.of(context).changeTheme(ThemeMode.dark);
                      }
                    }),
                const SizedBox(
                  height: 20,
                ),
                DropdownButton(
                  // Initial Value
                  value: dropdownvalue,

                  // Down Arrow Icon
                  icon: const Icon(Icons.keyboard_arrow_down),

                  // Array list of items
                  items: currency.map((String items) {
                    return DropdownMenuItem(
                      value: items,
                      child: Text(items),
                    );
                  }).toList(),
                  // After selecting the desired option,it will
                  // change button value to selected value
                  onChanged: (String? newValue) {
                    setState(() {
                      dropdownvalue = newValue!;
                    });
                  },
                ),
                const SizedBox(
                  height: 30,
                ),
                Container(
                  decoration: const BoxDecoration(
                      color: Color(0xffF4F4F6),
                      borderRadius: BorderRadius.all(Radius.circular(15.0))),
                  padding: const EdgeInsets.symmetric(horizontal: 15),
                  child: TextFormField(
                    decoration: InputDecoration(
                      fillColor: const Color(0xffF4F4F6),
                      hintText: "1000",
                      hintStyle: TextStyle(
                          fontSize: 16.56,
                          fontWeight: FontWeight.w500,
                          color: isDarkMode ? null : Colors.black),
                      enabledBorder: const OutlineInputBorder(
                        borderRadius:
                            const BorderRadius.all(Radius.circular(15.0)),
                        borderSide: BorderSide(color: const Color(0xffF4F4F6)),
                      ),
                      focusedBorder: const OutlineInputBorder(
                        borderRadius:
                            const BorderRadius.all(const Radius.circular(15.0)),
                        borderSide: BorderSide(color: const Color(0xffF4F4F6)),
                      ),
                      disabledBorder: const OutlineInputBorder(
                        borderRadius: BorderRadius.all(Radius.circular(15.0)),
                        borderSide: BorderSide(color: Color(0xffF4F4F6)),
                      ),
                    ),
                    style: TextStyle(
                        fontSize: 16.56,
                        fontWeight: FontWeight.w500,
                        color: isDarkMode ? null : Colors.black),
                    controller: phoneController,
                    keyboardType: TextInputType.phone,
                    onChanged: (value) {
                      // widget.email(value);
                      if (value.isEmpty) {
                        setState(() {
                          // widget.emailfield(true);
                        });
                      } else {
                        setState(() {});
                      }
                    },
                    validator: (value) {
                      if (value!.isEmpty) {
                        return "This field can't be empty";
                      }

                      return null;
                    },
                  ),
                ),
                const SizedBox(
                  height: 50,
                ),
                GestureDetector(
                  child: Container(
                    decoration: const BoxDecoration(
                        borderRadius: BorderRadius.all(Radius.circular(15)),
                        color: Color(0xff6C30F4)),
                    height: 65,
                    width: MediaQuery.of(context).size.width - 70,
                    padding: const EdgeInsets.symmetric(vertical: 15),
                    margin: const EdgeInsets.symmetric(
                        horizontal: 10, vertical: 10),
                    alignment: Alignment.center,
                    child: isloading
                        ? loadingWidget
                        : const Text(
                            "Checkout",
                            style: TextStyle(color: Colors.white, fontSize: 20),
                          ),
                  ),
                  onTap: () {
                    if (_formKey.currentState!.validate()) {
                      _handleCheckout(context);
                    }
                  },
                )
              ],
            ),
          ),
        ),
      ),
    );
  }

  _handleCheckout(BuildContext context) async {
    setState(() => isloading = true);
    _formKey.currentState?.save();
    Charge charge = Charge()
      ..amount = int.parse(phoneController.text) * 100 // In base currency
      ..email = 'sdkapp@email.com'
      ..currency = dropdownvalue;
    // ..card = _getCardFromUI();

    charge.reference = _getReference();

    try {
      var response = await plugin.checkout(
        context,
        charge: charge,
      );
      log('Response = $response');
      setState(() => isloading = false);
      _updateStatus(response.reference, '$response');
    } catch (e) {
      setState(() => isloading = false);
      _showMessage("Check console for error");
      rethrow;
    }
  }

  String _getReference() {
    String platform;
    if (!kIsWeb) {
      if (Platform.isIOS) {
        platform = 'iOS';
      } else {
        platform = 'Android';
      }
    } else {
      platform = "WEB";
    }
    return 'ChargedFrom${platform}_${DateTime.now().millisecondsSinceEpoch}';
  }

  _updateStatus(String? reference, String message) {
    _showMessage('Reference: $reference \n Response: $message',
        const Duration(seconds: 7));
  }

  _showMessage(String message,
      [Duration duration = const Duration(seconds: 4)]) {
    ScaffoldMessenger.of(context).showSnackBar(SnackBar(
      content: Text(message),
      duration: duration,
      action: SnackBarAction(
          label: 'CLOSE',
          onPressed: () =>
              ScaffoldMessenger.of(context).removeCurrentSnackBar()),
    ));
  }
}

const loadingWidget = SpinKitThreeBounce(
  color: Colors.white,
  size: 30.0,
);
